@@ -1,5 +1,5 @@
 /// Help text.
-pub const HELP: &str = r###"# felix v2.7.0
+pub const HELP: &str = r###"# felix v2.8.1
 A simple TUI file manager with vim-like keymapping.
 
 ## Usage
@@ -21,10 +21,12 @@ l / <Right> / <CR> :Open item or change directory.
 gg                 :Go to the top.
 G                  :Go to the bottom.
 z<CR>              :Go to the home directory.
-z{keyword}<CR>     :Jump to a directory that matches the keyword.
+z {keyword}<CR>    :Jump to a directory that matches the keyword.
                     (zoxide required)
 <C-o>              :Jump backward.
 <C-i>              :Jump forward.
+i{file name}<CR>   :Create a new empty file.
+I{dir name}<CR>    :Create a new empty directory.
 o                  :Open item in a new window.
 e                  :Unpack archive/compressed file.
 dd                 :Delete and yank item.
@@ -50,24 +52,25 @@ v                  :Toggle whether to show the preview.
 s                  :Toggle between vertical / horizontal split in the preview mode.
 <Alt-j>
  / <Alt-<Down>>    :Scroll down the preview text.
-<Alt-k> / 
+<Alt-k> 
  / <Alt-<Up>>      :Scroll up the preview text.
 <BS>               :Toggle whether to show hidden items.
 t                  :Toggle the sort order (name <-> modified time).
-:                  :Switch to the command line.
-  - <C-r>a         :In the command line, paste item name in register a.
 c                  :Switch to the rename mode.
-/                  :Search items by a keyword.
+/{keyword}         :Search items by a keyword.
 n                  :Go forward to the item that matches the keyword.
 N                  :Go backward to the item that matches the keyword.
-<Esc>              :Return to the normal mode.
+:                  :Switch to the command line.
+  - <C-r>a         :In the command line, paste item name in register a.
 :cd<CR>            :Go to the home directory.
-:cd{path}<CR>      :Go to the path.
+:cd {path}<CR>     :Go to the path.
 :e<CR>             :Reload the current directory.
 :trash<CR>         :Go to the trash directory.
 :empty<CR>         :Empty the trash directory.
 :h<CR>             :Show help.
 :q<CR>             :Exit.
+:{command}         :Execute a command e.g. :mkdir new_dir
+<Esc>              :Return to the normal mode.
 ZZ                 :Exit without cd to last working directory
                     (if `match_vim_exit_behavior` is `false`).
 ZQ                 :cd into the last working directory and exit
@@ -79,22 +82,25 @@ To preview images, you need to install chafa (>= v1.10.0).
 Please see https://hpjansson.org/chafa/
 
 ## Configuration
+
+*Both `config.yaml` and `config.yml` work.*
+
 ### Linux
-config file    : $XDG_CONFIG_HOME/felix/config.yaml
+config file    : $XDG_CONFIG_HOME/felix/config.yaml(config.yml)
 trash directory: $XDG_DATA_HOME/felix/trash
 log files      : $XDG_DATA_HOME/felix/log
 
 ### macOS
 On macOS, felix looks for the config file in the following locations:
 
-1. `$HOME/Library/Application Support/felix/config.yaml`
+1. `$HOME/Library/Application Support/felix/config.yaml(config.yml)`
 2. `$HOME/.config/felix/config.yaml`
 
 trash directory: $HOME/Library/Application Support/felix/trash
 log files      : $HOME/Library/Application Support/felix/log
 
 ### Windows
-config file     : $PROFILE\\AppData\\Roaming\\felix\\config.yaml
+config file     : $PROFILE\\AppData\\Roaming\\felix\\config.yaml(config.yml)
 trash directory : $PROFILE\\AppData\\Local\\felix\\trash
 log files       : $PROFILE\\AppData\\Local\\felix\\log
 
